#
# spec file for package ghc-vivid-osc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name vivid-osc
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.5.0.0
Release:        1.7
Summary:        Open Sound Control encode/decode
License:        GPL-1.0-or-later
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-cereal-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-time-devel
%if %{with tests}
BuildRequires:  ghc-microspec-devel
%endif

%description
Small, simple, and well-tested implementation of the Open Sound Control message
format.

Example usage:

>>> :set -XOverloadedStrings >>> msg = OSC "/foo" [OSC_S "bar", OSC_I 9, OSC_F
0.1, OSC_B "this-is-binary"] >>> :t msg > msg :: OSC >>> :t encodeOSC msg >
encodeOSC msg :: ByteString >>> decodeOSC (encodeOSC msg) == Right msg > True

Sending it over UDP (e.g. to TidalCycles), using the 'network' package:

' &#123;&#45;# LANGUAGE OverloadedStrings #&#45;&#125; '

> import Network.Socket > import Network.Socket.ByteString as SB > > import
Vivid.OSC > > main = do > -- Boring Network.Socket setup: > (a:_) <-
getAddrInfo Nothing (Just "127.0.0.1") (Just "57120") > s <- socket (addrFamily
a) Datagram defaultProtocol > connect s (addrAddress a) > > -- The interesting
part: > SB.send s $ encodeOSC $ > OSC "/play2" [OSC_S "cps", OSC_F 1.2, OSC_S
"s", OSC_S "bd"].

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files

%changelog
* Wed Dec 26 2018 psimons@suse.com
- Add vivid-osc at version 0.5.0.0.
